@@ -1,6 +1,7 @@
 from ipaddress import ip_network
-from kvirt.common import error, success, pprint, warning, get_kubectl, info2, container_mode, kube_create_app
-from kvirt.common import deploy_cloud_storage, wait_cloud_dns, update_etc_hosts, fix_typos, get_cluster_api_vips
+from kvirt.common import error, success, pprint, warning, get_kubectl, info2, container_mode, create_app_generic
+from kvirt.common import deploy_cloud_storage, wait_cloud_dns, update_etc_hosts, fix_typos, get_new_vip
+from kvirt.common import wait_for_nodes
 import os
 import re
 from random import choice
@@ -11,17 +12,18 @@ from tempfile import NamedTemporaryFile
 from time import sleep
 from yaml import safe_dump, safe_load
 
-cloud_providers = ['aws', 'azure', 'gcp', 'ibm']
+cloud_providers = ['aws', 'azure', 'gcp', 'ibm', 'hcloud']
 
 
 def update_ip_alias(config, nodes):
+    failure = False
     timeout = 0
     cmd_one = ['kubectl', 'get', 'nodes', '-o=jsonpath={range .items[?(@.spec.podCIDR)]}{.metadata.name}{\'\\n\'}{end}']
     while True:
         if timeout > 240:
-            error(f"Timeout waiting for {nodes} nodes to have a Pod CIDR assigned")
-            return
-        pprint(f"Waiting 5s for {nodes} nodes to have a Pod CIDR assigned")
+            error(f"Timeout waiting for {nodes} nodes to have a Pod cidr assigned")
+            return 1
+        pprint(f"Waiting 5s for {nodes} nodes to have a Pod cidr assigned")
         result = run(cmd_one, capture_output=True, text=True)
         current_nodes = len(result.stdout.splitlines())
         if current_nodes == nodes:
@@ -30,11 +32,14 @@ def update_ip_alias(config, nodes):
             sleep(5)
             timeout += 5
     for node in safe_load(os.popen("kubectl get node -o yaml").read())['items']:
+        name = node['metadata']['name']
         try:
-            name, pod_cidr = node['metadata']['name'], node['spec']['podCIDR']
+            pod_cidr = node['spec']['podCIDR']
             config.k.update_aliases(name, pod_cidr)
         except KeyError as e:
-            error(f"Hit Error: {e}")
+            error(f"Hit Error with node {name}: {e}")
+            failure = True
+    return 1 if failure else 0
 
 
 def scale(config, plandir, cluster, overrides):
@@ -103,9 +108,13 @@ def scale(config, plandir, cluster, overrides):
         result = config.plan(plan, inputfile=f'{plandir}/{role}.yml', overrides=overrides, threaded=threaded)
         if result['result'] != 'success':
             return result
+        elif result.get('newvms', []):
+            pprint(f"{role.capitalize()} nodes will join the cluster in a few minutes")
     if cloud_native and provider == 'gcp':
         pprint("Updating ip alias ranges")
-        update_ip_alias(config, ctlplanes + workers)
+        result = update_ip_alias(config, ctlplanes + workers)
+        if result != 0:
+            return {'result': 'failure', 'reason': "Issue when updating ip alias ranges"}
     return {'result': 'success'}
 
 
@@ -115,13 +124,14 @@ def create(config, plandir, cluster, overrides):
     data = safe_load(open(f'{plandir}/kcli_default.yml'))
     data.update(overrides)
     fix_typos(data)
+    storedparameters = data.get('storedparameters', True)
     cloud_dns = data['cloud_dns']
     data['cloud_lb'] = overrides.get('cloud_lb', provider in cloud_providers and data['ctlplanes'] > 1)
     cloud_lb = data['cloud_lb']
     cloud_storage = data['cloud_storage']
     cloud_native = data['cloud_native']
-    data['cluster'] = overrides.get('cluster') or cluster or 'myk3s'
-    plan = cluster if cluster is not None else data['cluster']
+    data['cluster'] = cluster
+    plan = cluster
     data['kube'] = data['cluster']
     data['kubetype'] = 'k3s'
     autoscale = data['autoscale']
@@ -143,15 +153,12 @@ def create(config, plandir, cluster, overrides):
         elif api_ip is None:
             networkinfo = k.info_network(network)
             if provider == 'kvm' and networkinfo['type'] == 'routed':
-                vip_mappings = get_cluster_api_vips()
                 cidr = networkinfo['cidr']
                 if cidr == 'N/A':
                     msg = "Couldnt gather an api_ip from your specified network"
                     return {'result': 'failure', 'reason': msg}
                 api_index = 2 if ':' in cidr else -3
-                if network in vip_mappings:
-                    api_index -= api_index + vip_mappings[network] if ':' in cidr else api_index - vip_mappings[network]
-                api_ip = str(ip_network(cidr)[api_index])
+                api_ip = str(get_new_vip(network, ipv6=':' in cidr) or ip_network(cidr)[api_index])
                 warning(f"Using {api_ip} as api_ip")
                 data['api_ip'] = api_ip
                 data['automatic_api_ip'] = True
@@ -172,7 +179,6 @@ def create(config, plandir, cluster, overrides):
             if data.get('virtual_router_id') is None:
                 data['virtual_router_id'] = hash(data['cluster']) % 254 + 1
                 pprint(f"Using keepalived virtual_router_id {data['virtual_router_id']}")
-                virtual_router_id = data.get('virtual_router_id')
             if data.get('auth_pass') is None:
                 auth_pass = ''.join(choice(ascii_letters + digits) for i in range(5))
                 data['auth_pass'] = auth_pass
@@ -207,21 +213,22 @@ def create(config, plandir, cluster, overrides):
     first_info = config.k.info(f'{cluster}-ctlplane-0')
     first_ip = first_info.get('private_ip') or first_info.get('ip')
     data['first_ip'] = first_ip
-    with open(f"{clusterdir}/kcli_parameters.yml", 'w') as p:
-        installparam = overrides.copy()
-        installparam['client'] = config.client
-        installparam['cluster'] = cluster
-        installparam['api_ip'] = api_ip
-        installparam['first_ip'] = first_ip
-        installparam['plan'] = plan
-        installparam['kubetype'] = 'k3s'
-        installparam['image'] = image
-        if not cloud_lb and ctlplanes > 1:
-            installparam['virtual_router_id'] = virtual_router_id
-            installparam['auth_pass'] = auth_pass
-        if 'automatic_api_ip' in data:
-            installparam['automatic_api_ip'] = True
-        safe_dump(installparam, p, default_flow_style=False, encoding='utf-8', allow_unicode=True)
+    if storedparameters:
+        with open(f"{clusterdir}/kcli_parameters.yml", 'w') as p:
+            installparam = overrides.copy()
+            installparam['client'] = config.client
+            installparam['cluster'] = cluster
+            installparam['api_ip'] = api_ip
+            installparam['first_ip'] = first_ip
+            installparam['plan'] = plan
+            installparam['kubetype'] = 'k3s'
+            installparam['image'] = image
+            if not cloud_lb and ctlplanes > 1:
+                installparam['virtual_router_id'] = data['virtual_router_id']
+                installparam['auth_pass'] = data['auth_pass']
+            if 'automatic_api_ip' in data:
+                installparam['automatic_api_ip'] = True
+            safe_dump(installparam, p, default_flow_style=False, encoding='utf-8', allow_unicode=True)
     for role in ['ctlplanes', 'workers']:
         if (role == 'ctlplanes' and ctlplanes == 1) or (role == 'workers' and workers == 0):
             continue
@@ -274,7 +281,12 @@ def create(config, plandir, cluster, overrides):
                 pprint(f"Adding app {app}")
                 if f'{app}_version' not in overrides:
                     app_data[f'{app}_version'] = 'latest'
-                kube_create_app(config, app, appdir, overrides=app_data)
+                create_app_generic(config, app, appdir, overrides=app_data)
+    if ctlplanes + workers > 1:
+        ready = wait_for_nodes(ctlplanes + workers)
+        if not ready:
+            msg = "Timeout waiting for all nodes to join"
+            return {'result': 'failure', 'reason': msg}
     if autoscale:
         config.import_in_kube(network=network, secure=True)
         with NamedTemporaryFile(mode='w+t') as temp:
@@ -291,5 +303,7 @@ def create(config, plandir, cluster, overrides):
             deploy_cloud_storage(config, cluster)
         if cloud_native and provider == 'gcp':
             pprint("Updating ip alias ranges")
-            update_ip_alias(config, ctlplanes + workers)
+            result = update_ip_alias(config, ctlplanes + workers)
+            if result != 0:
+                return {'result': 'failure', 'reason': "Issue when updating ip alias ranges"}
     return {'result': 'success'}
