@@ -710,6 +710,8 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
     data['sno'] = sno
     sno_wait = overrides.get('sno_wait') or baremetal_sno or data['api_ip'] is not None or sno_vm
     sno_disk = data['sno_disk']
+    if sno_disk is not None and not sno_disk.startswith('/dev/'):
+        sno_disk = f'/dev/{sno_disk}'
     sno_ctlplanes = data['sno_ctlplanes'] or baremetal_ctlplane
     sno_workers = data['sno_workers']
     sno_telco = data['sno_telco']
@@ -1171,6 +1173,13 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
             if not f.endswith('.yml') and not f.endswith('.yaml'):
                 warning(f"Skipping manifest {f}")
                 continue
+            if f == '99-openshift-disconnected-catalog.yaml':
+                if disconnected_url is not None:
+                    content = content.replace('REGISTRY', disconnected_url).replace('TAG', OPENSHIFT_TAG)
+                else:
+                    continue
+            if f == '98-var-lib-containers-partitioned.yaml':
+                content = content.replace('SNO_DISK', sno_disk or '/dev/sda')
             pprint(f"Injecting manifest {f}")
             with open(f'{clusterdir}/openshift/{f}', 'w') as f:
                 f.write(content)
