@@ -227,13 +227,19 @@ def max_ocp_version(version1, version2):
     return version1 if version1 > version2 else version2
 
 
+def filter_bgp_peers(peers, num):
+    peers = peers.copy()
+    del peers[num]
+    return peers
+
+
 jinjafilters = {'basename': basename, 'dirname': dirname, 'diskpath': diskpath, 'kubenodes': kubenodes, 'none': none,
                 'type': _type, 'certificate': certificate, 'base64': base64, 'github_version': github_version,
                 'defaultnodes': defaultnodes, 'wait_crd': wait_crd, 'local_ip': local_ip, 'network_ip': network_ip,
                 'kcli_info': kcli_info, 'find_manifests': find_manifests, 'exists': exists, 'ipv6_wrap': ipv6_wrap,
                 'has_ctlplane': has_ctlplane, 'wait_csv': wait_csv, 'count': count, 'pwd_path': pwd_path,
                 'min_ocp_version': min_ocp_version, 'max_ocp_version': max_ocp_version, 'real_path': real_path,
-                'read_file': read_file}
+                'read_file': read_file, 'filter_bgp_peers': filter_bgp_peers}
 
 
 class FilterModule(object):
